==> v4_navigation_engine-0.1.80.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/View/MyNavigationView+SlideButtonDelegate+MyPauseRunDelegate.swift <==
//
//  MyNavigationView+SlideButtonDelegate+MyPauseRunDelegate.swift
//  NavigationUI
//
//  Created by Hassine on 03/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import Foundation

import LiquidFloatingActionButton


extension MyNavigationView : SlideButtonDelegate, MyPauseRunDelegate
{
    func playMyNavigation() {
        isPaused = false
       timerCourse = Timer.scheduledTimer(timeInterval: 1, target: self, selector: #selector(self.timerDuringSmartRun), userInfo: nil, repeats: true)
        navigationService?.start()
    }
    
    func manageVoice() {
        if isMuted
        {
            self.voiceController?.audioPlayer?.volume = 1
            PlayerManager.shared.audioPlayerPoiDescriptionQueue?.volume = 1
        }
        else
        {
            self.voiceController?.audioPlayer?.volume = 0
            PlayerManager.shared.audioPlayerPoiDescriptionQueue?.volume = 0
        }
        isMuted = !isMuted
    }
    
    func stopMyNavigation() {
        deinitNavigation()

        flutterOnNavigationFinished()

        var h = Historic.init()
        h.time = runTime_seconds

        if distanceTitle_lbl.text == "m"{
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) )
        } else {
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) * 1000)
        }

        //h.mediumSpeed = Double(speedValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0.0

        h.mediumSpeed = getMediumSpeed(distance:  h.distanceTravelled , timeInSecond: h.time)

        if let weight = Int(user?.weight ?? "") {
            h.calories = calculateCalorie(h.mediumSpeed, userWeight: weight, nbMinuteRanOnSR: Int(Double(h.time)/60))
        } else {
            h.calories = nil
        }
        
        


    }
    
    func calculateCalorie(_ userMediumSpeed_KmH: Double, userWeight: Int, nbMinuteRanOnSR:Int) -> Int {
        //Calcul via la formule disponible ici :
        // http://www.regivia.com/index.php/comment-maigrir-conseils-solutions-trucs-et-astuces/calcul-des-depenses-energetiques-en-calories-par-sports-et-activites/depenses-caloriques-consommees-pour-la-course-a-pied-le-running-footing-ou-jogging/
        
        //Loading user weight :
        var MET: Double = 6 //level of effort : define by the medium user speed
        if userMediumSpeed_KmH > 6 {
            MET = userMediumSpeed_KmH
        }else if userMediumSpeed_KmH < 1 {
            MET = 0
        }
        let burnedCalorie: Int = (Int(MET) * 3 * userWeight/200) * nbMinuteRanOnSR
        return burnedCalorie
    }
    
    
    
    func buttonStatus(status: String, sender: MMSlidingButton) {
        isPaused = true
        timerSmartFact?.invalidate()
        timerCourse.invalidate()
         navigationService?.stop()
        
        
        let router = MyNavigationRouter.init()
        let c = router.createPauseController(whiteLabel: self.whiteLabel!, gpsColor: self.gpsColor)
       // let c = r.createPauseController()
        c.delegate = self
        var h = Historic.init()
        h.time = runTime_seconds
        
        if distanceTitle_lbl.text == "m"
        {
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) )
        }
           else if distanceTitle_lbl.text == "pi" || distanceTitle_lbl.text == "ft"
            {
                h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) )/5280
            }
        else
        {
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) * 1000)
        }
        
        
        
        h.mediumSpeed = getMediumSpeed(distance: Int(traveledDistance), timeInSecond: h.time)
        
        
        c.historic = h
        c.isMuted = isMuted
        self.present(c, animated: true) {
             PlayerManager.shared.stopSpeaking()
            self.pauseRun_slideBtn.reset()
            
        }
    }
    
    func checkBestLanguage() -> Void {
         (languageRessource,languageAndCountry ) = presenter!.checkBestLanguage(pois: pois)
    }
    
    func getMediumSpeed(distance : Int, timeInSecond : Int) -> Double {
        if timeInSecond != 0 {
            if measurementSystem == .metric
                {
                    let speed  = Double(Double(distance)/1000) / Double(Double(timeInSecond)/3600)
                               return speed
            }
            else
            {
                let speed  = Double(Double(distance)/1000) / Double(Double(timeInSecond)/3600)
                           return speed *  0.6213711922
               
            }
           
        }else{
            return 0
        }
    }
}

==> v4_navigation_engine-0.1.86.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/View/MyNavigationView+SlideButtonDelegate+MyPauseRunDelegate.swift <==
//
//  MyNavigationView+SlideButtonDelegate+MyPauseRunDelegate.swift
//  NavigationUI
//
//  Created by Hassine on 03/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import Foundation

import LiquidFloatingActionButton


extension MyNavigationView : SlideButtonDelegate, MyPauseRunDelegate
{
    func playMyNavigation() {
        isPaused = false
       timerCourse = Timer.scheduledTimer(timeInterval: 1, target: self, selector: #selector(self.timerDuringSmartRun), userInfo: nil, repeats: true)
        navigationService?.start()
    }
    
    func manageVoice() {
        if isMuted
        {
            self.voiceController?.audioPlayer?.volume = 1
            PlayerManager.shared.audioPlayerPoiDescriptionQueue?.volume = 1
        }
        else
        {
            self.voiceController?.audioPlayer?.volume = 0
            PlayerManager.shared.audioPlayerPoiDescriptionQueue?.volume = 0
        }
        isMuted = !isMuted
    }
    
    func stopMyNavigation() {
        deinitNavigation()

        flutterOnNavigationFinished()

        var h = Historic.init()
        h.time = runTime_seconds

        if distanceTitle_lbl.text == "m"{
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) )
        } else {
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) * 1000)
        }

        //h.mediumSpeed = Double(speedValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0.0

        h.mediumSpeed = getMediumSpeed(distance:  h.distanceTravelled , timeInSecond: h.time)

        if let weight = Int(user?.weight ?? "") {
            h.calories = calculateCalorie(h.mediumSpeed, userWeight: weight, nbMinuteRanOnSR: Int(Double(h.time)/60))
        } else {
            h.calories = nil
        }
        
        


    }
    
    func calculateCalorie(_ userMediumSpeed_KmH: Double, userWeight: Int, nbMinuteRanOnSR:Int) -> Int {
        //Calcul via la formule disponible ici :
        // http://www.regivia.com/index.php/comment-maigrir-conseils-solutions-trucs-et-astuces/calcul-des-depenses-energetiques-en-calories-par-sports-et-activites/depenses-caloriques-consommees-pour-la-course-a-pied-le-running-footing-ou-jogging/
        
        //Loading user weight :
        var MET: Double = 6 //level of effort : define by the medium user speed
        if userMediumSpeed_KmH > 6 {
            MET = userMediumSpeed_KmH
        }else if userMediumSpeed_KmH < 1 {
            MET = 0
        }
        let burnedCalorie: Int = (Int(MET) * 3 * userWeight/200) * nbMinuteRanOnSR
        return burnedCalorie
    }
    
    
    
    func buttonStatus(status: String, sender: MMSlidingButton) {
        isPaused = true
        timerSmartFact?.invalidate()
        timerCourse.invalidate()
         navigationService?.stop()
        
        
        let router = MyNavigationRouter.init()
        let c = router.createPauseController(whiteLabel: self.whiteLabel!, gpsColor: self.gpsColor)
       // let c = r.createPauseController()
        c.delegate = self
        var h = Historic.init()
        h.time = runTime_seconds
        
        if distanceTitle_lbl.text == "m"
        {
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) )
        }
           else if distanceTitle_lbl.text == "pi" || distanceTitle_lbl.text == "ft"
            {
                h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) )/5280
            }
        else
        {
            h.distanceTravelled = Int((Double(distanceValue_lbl.text!.replacingOccurrences(of: ",", with: ".")) ?? 0 ) * 1000)
        }
        
        
        
        h.mediumSpeed = getMediumSpeed(distance: Int(traveledDistance), timeInSecond: h.time)
        
        
        c.historic = h
        c.isMuted = isMuted
        self.present(c, animated: true) {
             PlayerManager.shared.stopSpeaking()
            self.pauseRun_slideBtn.reset()
            
        }
    }
    
    func checkBestLanguage() -> Void {
        (languageRessource,languageAndCountry ) = presenter!.checkBestLanguage(languages: self.languages)
    }
    
    func getMediumSpeed(distance : Int, timeInSecond : Int) -> Double {
        if timeInSecond != 0 {
            if measurementSystem == .metric
                {
                    let speed  = Double(Double(distance)/1000) / Double(Double(timeInSecond)/3600)
                               return speed
            }
            else
            {
                let speed  = Double(Double(distance)/1000) / Double(Double(timeInSecond)/3600)
                           return speed *  0.6213711922
               
            }
           
        }else{
            return 0
        }
    }
}
